[PATCH 4/4] d3d/tests: Rename fog_interpolation_test for consistency.

Stefan Dösinger stefan at codeweavers.com
Thu Nov 27 05:12:36 CST 2014


This keeps ddraw7.c consistent. d3d{8,9}/tests/visual.c is already
inconsistent.
---
 dlls/d3d8/tests/visual.c  | 6 +++---
 dlls/d3d9/tests/visual.c  | 6 +++---
 dlls/ddraw/tests/ddraw7.c | 6 +++---
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/dlls/d3d8/tests/visual.c b/dlls/d3d8/tests/visual.c
index ec406f1..a8a771e 100644
--- a/dlls/d3d8/tests/visual.c
+++ b/dlls/d3d8/tests/visual.c
@@ -5217,7 +5217,7 @@ done:
     DestroyWindow(window);
 }
 
-static void fog_interpolation_test(void)
+static void test_fog_interpolation(void)
 {
     HRESULT hr;
     IDirect3DDevice8 *device;
@@ -5433,7 +5433,7 @@ static void test_negative_fixedfunction_fog(void)
          * parameters to 0.0 and 1.0 in the table fog case. */
         {D3DFVF_XYZRHW, tquad,  sizeof(*tquad), &identity, {-1.0f}, {0.0f},
                 D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
         /* fog_interpolation_test shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
         {D3DFVF_XYZ,    quad,   sizeof(*quad),  &zero,     { 0.0f}, {1.0f},
@@ -5565,6 +5565,6 @@ START_TEST(visual)
     volume_v16u16_test();
     add_dirty_rect_test();
     test_3dc_formats();
-    fog_interpolation_test();
+    test_fog_interpolation();
     test_negative_fixedfunction_fog();
 }
@@ -5433,7 +5433,7 @@ static void test_negative_fixedfunction_fog(void)
         {D3DFVF_XYZRHW, tquad,  sizeof(*tquad), &identity, {-1.0f}, {0.0f},
                 D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
-        /* fog_interpolation_test shows that vertex fog evaluates the fog
+        /* test_fog_interpolation shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
diff --git a/dlls/d3d9/tests/visual.c b/dlls/d3d9/tests/visual.c
index 59f5ba8..d1aa3d4 100644
--- a/dlls/d3d9/tests/visual.c
+++ b/dlls/d3d9/tests/visual.c
@@ -16820,7 +16820,7 @@ done:
     DestroyWindow(window);
 }
 
-static void fog_interpolation_test(void)
+static void test_fog_interpolation(void)
 {
     HRESULT hr;
     IDirect3DDevice9 *device;
@@ -17036,7 +17036,7 @@ static void test_negative_fixedfunction_fog(void)
          * parameters to 0.0 and 1.0 in the table fog case. */
         {D3DFVF_XYZRHW, tquad,  sizeof(*tquad), &identity, {-1.0f}, {0.0f},
                 D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
         /* fog_interpolation_test shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
         {D3DFVF_XYZ,    quad,   sizeof(*quad),  &zero,     { 0.0f}, {1.0f},
@@ -17226,6 +17226,6 @@ START_TEST(visual)
     stencil_cull_test();
     test_per_stage_constant();
     test_3dc_formats();
-    fog_interpolation_test();
+    test_fog_interpolation();
     test_negative_fixedfunction_fog();
 }
@@ -17036,7 +17036,7 @@ static void test_negative_fixedfunction_fog(void)
         {D3DFVF_XYZRHW, tquad,  sizeof(*tquad), &identity, {-1.0f}, {0.0f},
                 D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
-        /* fog_interpolation_test shows that vertex fog evaluates the fog
+        /* test_fog_interpolation shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
diff --git a/dlls/ddraw/tests/ddraw7.c b/dlls/ddraw/tests/ddraw7.c
index e9510c4..0ac7d7e 100644
--- a/dlls/ddraw/tests/ddraw7.c
+++ b/dlls/ddraw/tests/ddraw7.c
@@ -7878,7 +7878,7 @@ static void test_surface_desc_lock(void)
     DestroyWindow(window);
 }
 
-static void fog_interpolation_test(void)
+static void test_fog_interpolation(void)
 {
     HRESULT hr;
     IDirect3DDevice7 *device;
@@ -8069,7 +8069,7 @@ static void test_negative_fixedfunction_fog(void)
         /* r200 GPUs and presumably all d3d8 and older HW clamp the fog
          * parameters to 0.0 and 1.0 in the table fog case. */
         {D3DFVF_XYZRHW, tquad,  &identity, {-1.0f}, {0.0f}, D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
         /* fog_interpolation_test shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
         {D3DFVF_XYZ,    quad,   &zero,     { 0.0f}, {1.0f}, D3DFOG_LINEAR, D3DFOG_NONE,   0x00808000, 0x00808000},
@@ -8229,6 +8229,6 @@ START_TEST(ddraw7)
     test_lost_device();
     test_resource_priority();
     test_surface_desc_lock();
-    fog_interpolation_test();
+    test_fog_interpolation();
     test_negative_fixedfunction_fog();
 }
@@ -8069,7 +8069,7 @@ static void test_negative_fixedfunction_fog(void)
          * parameters to 0.0 and 1.0 in the table fog case. */
         {D3DFVF_XYZRHW, tquad,  &identity, {-1.0f}, {0.0f}, D3DFOG_NONE,   D3DFOG_LINEAR, 0x00808000, 0x00ff0000},
-        /* fog_interpolation_test shows that vertex fog evaluates the fog
+        /* test_fog_interpolation shows that vertex fog evaluates the fog
          * equation in the vertex pipeline. Start = -1.0 && end = 0.0 shows
          * that the abs happens before the fog equation is evaluated. */
-- 
2.0.4




More information about the wine-patches mailing list